from ngsolve import *
from netgen.geom2d import unit_square

# ------------------------- DEFINITIONS -------------------------
def Grad2D(vec):
    return CoefficientFunction( (grad(vec),), dims=(2,2) )

# ------------------------- PARAMETERS -------------------------
k = 2                       # Polynomial oder for velocity-space                  

# -------------------------EXACT SOLUTION --------------------------------
from math import pi
u_ex = CoefficientFunction((sin(2*pi*x)*sin(2*pi*y),cos(2*pi*x)*cos(2*pi*y)))

# ------------------------- MESH -------------------------
mesh = Mesh(unit_square.GenerateMesh(maxh=0.2))

# ------------------------- FINITE ELEMENT SPACE -------------------------
V = VectorH1(mesh, order=k)

# ------------------------- FINITE ELEMENT METHOD -------------------------
u = V.TrialFunction()
v = V.TestFunction()

b = InnerProduct(Grad2D(u)*u_ex,v)

B = BilinearForm(V)
B += SymbolicBFI( b ).SetIntegrationRule(TRIG,IntegrationRule(TRIG,3*k-1))
with TaskManager(): 
    B.Assemble()

print(B.mat)

from numpy import *

M = B.mat.NumPy()